import { ActionRowBuilder, ApplicationCommandOptionData, ApplicationCommandOptionType, ButtonBuilder, ButtonStyle, CommandInteraction, PermissionFlagsBits } from "discord.js"
import { CBClient, Trade } from "../cbclient"
import { CHARACTERS } from "../characters"
import { Unit } from "../models/unit"
import { SlashCommand, createArgumentsObject } from "./slash"

interface TradeArguments {
    your_character: number
    their_character: number
}

export class TradeCommand implements SlashCommand {
	name = 'trade'
    description = 'Trade a character with someone'
    permission = []
    ownerOnly = false
    guildOnly = true
    //guildID = "739645806100873328" //for testing
    args: ApplicationCommandOptionData[] = [
        {
            name: 'your_character',
            type: ApplicationCommandOptionType.Integer,
            description: "The character you want to give",
            required: true
        },
        {
            name: 'their_character',
            type: ApplicationCommandOptionType.Integer,
            description: "The character you want to get",
            required: true
        }
    ]

	async execute(int: CommandInteraction) {
        const args = createArgumentsObject<TradeArguments>(int.options.data);
        const client = int.client as CBClient;

        const unit1 = await Unit.findOne( { where: { user_id: int.user.id, id: args.your_character } } );
        const unit2 = await Unit.findOne( { where: { id: args.their_character } } );

        if (!unit1) return int.reply({
            content: `You don't own that unit!`,
            ephemeral: true
        });
        if (!unit2) return int.reply({
            content: `You can't trade for a unit that doesn't exist!`,
            ephemeral: true
        });

        const tradeguy = int.guild!.members.resolve(unit2.user_id);
        if (!tradeguy) return int.reply({
            content: `Either something went wrong or you're trading with a ghost (something went wrong)`,
            ephemeral: true
        });

        const character1 = CHARACTERS.get(unit1.character_id)!;
        const character2 = CHARACTERS.get(unit2.character_id)!;

        const trade = new Trade(int.user, tradeguy.user, unit1, unit2, await int.reply({
            content: `${tradeguy}, ${int.user} wants to trade ${character1.name} for your ${character2.name}!\n**THIS IS A TRADE PLEASE DON'T MINDLESSLY CLICK THE BUTTON**`,
            fetchReply: true,
            components: [new ActionRowBuilder<ButtonBuilder>()
                .addComponents(
                    new ButtonBuilder()
                        .setCustomId('t'+int.user.id+tradeguy.user.id)
                        .setLabel('Yes, accept trade!')
                        .setStyle(ButtonStyle.Primary)
                )]
        }));
        return client.TRADES.set(trade.id, trade);
	}
};
